@@ -1,30 +1,14 @@
 /*
-    Copyright (C) 2012  Jan Grulich <grulja@gmail.com>
+    SPDX-FileCopyrightText: 2012 Jan Grulich <grulja@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
+#pragma once
 
-#ifndef LIBKGAPI2_OBJECTS_LOCATION_H
-#define LIBKGAPI2_OBJECTS_LOCATION_H
-
+#include "kgapilatitude_export.h"
 #include "object.h"
 #include "types.h"
-#include "kgapilatitude_export.h"
 
 #include <KContacts/Geo>
 
@@ -40,11 +24,9 @@ namespace KGAPI2
  * @author Jan Grulich <grulja@gmail.com>
  * @since 0.4
  */
-class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object,
-                                      public KContacts::Geo
+class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object, public KContacts::Geo
 {
-  public:
-
+public:
     /**
      * @brief Constructor
      */
@@ -85,7 +67,7 @@ class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object,
      *
      * @return Returns -1 when accuracy is not defined.
      */
-    qint32 accuracy() const;
+    Q_REQUIRED_RESULT qint32 accuracy() const;
 
     /**
      * @brief Sets accuracy of this location.
@@ -98,7 +80,7 @@ class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object,
      *
      * @return Returns -1 when speed is not defined.
      */
-    qint32 speed() const;
+    Q_REQUIRED_RESULT qint32 speed() const;
 
     /**
      * @brief Sets speed of this location.
@@ -111,7 +93,7 @@ class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object,
      *
      * @return Returns -1 when heading is not defined.
      */
-    qint32 heading() const;
+    Q_REQUIRED_RESULT qint32 heading() const;
 
     /**
      * @brief Sets heading of this location.
@@ -123,7 +105,7 @@ class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object,
      *
      * @return Returns 0 when altitude is not defined.
      */
-    qint32 altitude() const;
+    Q_REQUIRED_RESULT qint32 altitude() const;
 
     /**
      * @brief Sets altitude of this location.
@@ -135,20 +117,17 @@ class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object,
      *
      * @return Returns -1 when altitude accuracy is not defined.
      */
-    qint32 altitudeAccuracy() const;
+    Q_REQUIRED_RESULT qint32 altitudeAccuracy() const;
 
     /**
      * @brief Sets altitude accuracy of this location.
      */
     void setAltitudeAccuracy(qint32 altitudeAccuracy);
 
-  private:
+private:
     class Private;
-    Private * const d;
+    Private *const d;
     friend class Private;
-
 };
 
 } // namespace KGAPI2
-
-#endif // LOCATION_H
